@@ -126,10 +126,10 @@ Esys_StartAuthSession(
         r = Esys_StartAuthSession_Finish(esysContext, sessionHandle);
         /* This is just debug information about the reattempt to finish the
            command */
-        if ((r & ~TSS2_RC_LAYER_MASK) == TSS2_BASE_RC_TRY_AGAIN)
+        if (base_rc(r) == TSS2_BASE_RC_TRY_AGAIN)
             LOG_DEBUG("A layer below returned TRY_AGAIN: %" PRIx32
                       " => resubmitting command", r);
-    } while ((r & ~TSS2_RC_LAYER_MASK) == TSS2_BASE_RC_TRY_AGAIN);
+    } while (base_rc(r) == TSS2_BASE_RC_TRY_AGAIN);
 
     /* Restore the timeout value to the original value */
     esysContext->timeout = timeouttmp;
@@ -223,20 +223,15 @@ Esys_StartAuthSession_Async(
     TSS2_RC r2;
     r2 = iesys_compute_encrypted_salt(esysContext, tpmKeyNode,
                                       &encryptedSaltAux);
-    return_if_error(r2, "Error in parameter encryption.");
+    return_state_if_error(r2, _ESYS_STATE_INIT, "Error in parameter encryption.");
 
     if (nonceCaller == NULL) {
         r2 = iesys_crypto_hash_get_digest_size(authHash,&authHash_size);
-        if (r2 != TSS2_RC_SUCCESS) {
-            LOG_ERROR("Error: initialize auth session (%x).", r2);
-            return r2;
-        }
+        return_state_if_error(r2, _ESYS_STATE_INIT, "Error in hash_get_digest_size.");
+
         r2 = iesys_crypto_random2b(&esysContext->in.StartAuthSession.nonceCallerData,
                                    authHash_size);
-        if (r2 != TSS2_RC_SUCCESS) {
-            LOG_ERROR("Error: initialize auth session (%x).", r2);
-            return r2;
-        }
+        return_state_if_error(r2, _ESYS_STATE_INIT, "Error in crypto_random2b.");
         esysContext->in.StartAuthSession.nonceCaller
            = &esysContext->in.StartAuthSession.nonceCallerData;
         nonceCaller = esysContext->in.StartAuthSession.nonceCaller;
@@ -260,7 +255,19 @@ Esys_StartAuthSession_Async(
     iesys_compute_session_value(esysContext->session_tab[2], NULL, NULL);
 
     /* Generate the auth values and set them in the SAPI command buffer */
-    r = iesys_gen_auths(esysContext, tpmKeyNode, bindNode, NULL, &auths);
+
+    RSRC_NODE_T none;
+    size_t offset = 0;
+    none.rsrc.handle = TPM2_RH_NULL;
+    none.rsrc.rsrcType = IESYSC_WITHOUT_MISC_RSRC;
+    r = Tss2_MU_TPM2_HANDLE_Marshal(TPM2_RH_NULL,
+                                none.rsrc.name.name,
+                                sizeof(none.rsrc.name.name),
+                                &offset);
+    return_state_if_error(r, _ESYS_STATE_INIT, "Marshaling TPM handle.");
+    none.rsrc.name.size = offset;
+    r = iesys_gen_auths(esysContext, tpmKeyNode ? tpmKeyNode : &none,
+                                     bindNode ? bindNode : &none, NULL, &auths);
     return_state_if_error(r, _ESYS_STATE_INIT,
                           "Error in computation of auth values");
 
@@ -351,7 +358,7 @@ Esys_StartAuthSession_Finish(
 
     /* Receive the TPM response and handle resubmissions if necessary. */
     r = Tss2_Sys_ExecuteFinish(esysContext->sys, esysContext->timeout);
-    if ((r & ~TSS2_RC_LAYER_MASK) == TSS2_BASE_RC_TRY_AGAIN) {
+    if (base_rc(r) == TSS2_BASE_RC_TRY_AGAIN) {
         LOG_DEBUG("A layer below returned TRY_AGAIN: %" PRIx32, r);
         esysContext->state = _ESYS_STATE_SENT;
         goto error_cleanup;
@@ -475,12 +482,8 @@ Esys_StartAuthSession_Finish(
 
         sessionHandleNode->rsrc.misc.rsrc_session.sessionKey.size = authHash_size;
         LOGBLOB_DEBUG(&sessionHandleNode->rsrc.misc.rsrc_session.sessionKey
-                      .buffer[0],
-                      sessionHandleNode->rsrc.misc.rsrc_session.sessionKey.size,
-                      "Session Key");
+                      .buffer[0], authHash_size, "Session Key");
         return_if_error(r,"Error KDFa");
-
-        sessionHandleNode->rsrc.misc.rsrc_session.sessionKey.size = authHash_size;
     }
     size_t offset = 0;
     r = Tss2_MU_TPM2_HANDLE_Marshal(sessionHandleNode->rsrc.handle,
@@ -490,6 +493,7 @@ Esys_StartAuthSession_Finish(
     goto_if_error(r, "Marshal session name", error_cleanup);
 
     sessionHandleNode->rsrc.name.size = offset;
+    memset(&esysContext->salt, '\0', sizeof(esysContext->salt));
     esysContext->state = _ESYS_STATE_INIT;
 
     return TSS2_RC_SUCCESS;
