@@ -82,24 +82,9 @@ doLogBlob(log_level loglevel, const char *module, log_level logdefault,
 {
     if (unlikely(*status == LOGLEVEL_UNDEFINED))
         *status = getLogLevel(module, logdefault);
-
     if (loglevel > *status)
         return;
 
-    size_t width = 8;
-    size_t buffer_size = (size * 2) + (size / width) * 2 + 1;
-    char buffer[buffer_size];
-    buffer[0] = '\0';
-    for (size_t i = 0, off = 0; i < size && off < buffer_size; i++, off+=2) {
-        if (width < buffer_size && i % width == 0) {
-            *(&buffer[0] + off) = '\n';
-            off += 1;
-            *(&buffer[0] + off) = '\t';
-            off += 1;
-        }
-        sprintf(&buffer[0] + off, "%02x", blob[i]);
-    }
-
     va_list vaargs;
     va_start(vaargs, fmt);
     /* TODO: Unfortunately, vsnprintf(NULL, 0, ...) do not behave the same as
@@ -112,7 +97,54 @@ doLogBlob(log_level loglevel, const char *module, log_level logdefault,
     va_end(vaargs);
 
     doLog(loglevel, module, logdefault, status, file, func, line,
-          "%s (size=%zi): %s", msg, size, buffer);
+          "%s (size=%zi):", msg, size);
+
+    unsigned int i, y, x, off, off2;
+    unsigned int width = 16;
+#define LINE_LEN 64
+    char buffer[LINE_LEN];
+
+    for (i = 1, off = 0, off2 = 0; i <= size; i++) {
+        if (i == 1) {
+            sprintf(&buffer[off], "%04x: ", i - 1);
+            off += 6;
+        }
+
+        /* data output */
+        sprintf(&buffer[off], "%02x", blob[i-1]);
+        off += 2;
+
+        /* ASCII output */
+        if ((i % width == 0 && i > 1) || i == size) {
+            sprintf(&buffer[off], "  ");
+            off += 2;
+            /* Align to the right */
+            for (x = off; x < width * 2 + 8; x++) {
+                sprintf(&buffer[off], " ");
+                off++;
+            }
+
+            /* Account for a line that is not 'full' */
+            unsigned int less = width - (i % width);
+            if (less == width)
+                less = 0;
+
+            for (y = 0; y < width - less; y++) {
+                if (isgraph(blob[off2 + y])) {
+                    sprintf(&buffer[y + off], "%c", blob[off2 + y]);
+                } else {
+                    sprintf(&buffer[y + off], "%c", '.');
+                }
+            }
+            /* print the line and restart */
+            fprintf (stderr, "%s\n", buffer);
+            off2 = i;
+            off = 0;
+            memset(buffer, '\0', LINE_LEN);
+            sprintf(&buffer[off], "%04x: ", i);
+            off += 6;
+        }
+    }
 }
 
 void
@@ -144,7 +176,8 @@ doLog(log_level loglevel, const char *module, log_level logdefault,
 static log_level
 log_stringlevel(const char *n)
 {
-    for(log_level i = 0; i < sizeof(log_strings)/sizeof(log_strings[0]); i++) {
+    log_level i;
+    for(i = 0; i < sizeof(log_strings)/sizeof(log_strings[0]); i++) {
         if (case_insensitive_strncmp(log_strings[i], n, strlen(log_strings[i])) == 0) {
             return i;
         }
@@ -156,8 +189,8 @@ static log_level
 getLogLevel(const char *module, log_level logdefault)
 {
     log_level loglevel = logdefault;
-    char *envlevel = getenv("TSS2_LOG");
-    char *i = envlevel;
+    const char *envlevel = getenv("TSS2_LOG");
+    const char *i = envlevel;
     if (envlevel == NULL)
         return loglevel;
     while ((i = strchr(i, '+')) != NULL) {
