@@ -20,7 +20,7 @@
 /** This test is intended to test Esys_ECDH_KeyGen based on an ECC key
  *  created with Esys_CreatePrimary.
  *
- * Tested ESAPI commands:
+ * Tested ESYS commands:
  *  - Esys_CreatePrimary() (M)
  *  - Esys_ECDH_KeyGen() (M)
  *  - Esys_FlushContext() (M)
@@ -47,6 +47,14 @@ test_esys_ecdh_keygen(ESYS_CONTEXT * esys_context)
         .buffer = {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20}
     };
 
+    TPM2B_PUBLIC *outPublic = NULL;
+    TPM2B_CREATION_DATA *creationData = NULL;
+    TPM2B_DIGEST *creationHash = NULL;
+    TPMT_TK_CREATION *creationTicket = NULL;
+
+    TPM2B_ECC_POINT *zPoint = NULL;
+    TPM2B_ECC_POINT *pubPoint = NULL;
+
     memset(&sessionAttributes, 0, sizeof sessionAttributes);
 
     r = Esys_StartAuthSession(esys_context, ESYS_TR_NONE, ESYS_TR_NONE,
@@ -124,20 +132,12 @@ test_esys_ecdh_keygen(ESYS_CONTEXT * esys_context)
     r = Esys_TR_SetAuth(esys_context, ESYS_TR_RH_OWNER, &authValue);
     goto_if_error(r, "Error: TR_SetAuth", error);
 
-    TPM2B_PUBLIC *outPublic;
-    TPM2B_CREATION_DATA *creationData;
-    TPM2B_DIGEST *creationHash;
-    TPMT_TK_CREATION *creationTicket;
-
     r = Esys_CreatePrimary(esys_context, ESYS_TR_RH_OWNER, session,
                            ESYS_TR_NONE, ESYS_TR_NONE, &inSensitive, &inPublic,
                            &outsideInfo, &creationPCR, &eccHandle,
                            &outPublic, &creationData, &creationHash,
                            &creationTicket);
-    goto_if_error(r, "Error esapi create primary", error);
-
-    TPM2B_ECC_POINT *zPoint;
-    TPM2B_ECC_POINT *pubPoint;
+    goto_if_error(r, "Error esys create primary", error);
 
     r = Esys_ECDH_KeyGen(
         esys_context,
@@ -155,6 +155,13 @@ test_esys_ecdh_keygen(ESYS_CONTEXT * esys_context)
     r = Esys_FlushContext(esys_context, session);
     goto_if_error(r, "Flushing context", error);
 
+    Esys_Free(outPublic);
+    Esys_Free(creationData);
+    Esys_Free(creationHash);
+    Esys_Free(creationTicket);
+
+    Esys_Free(zPoint);
+    Esys_Free(pubPoint);
     return EXIT_SUCCESS;
 
  error:
@@ -171,10 +178,17 @@ test_esys_ecdh_keygen(ESYS_CONTEXT * esys_context)
             LOG_ERROR("Cleanup eccHandle failed.");
         }
     }
+    Esys_Free(outPublic);
+    Esys_Free(creationData);
+    Esys_Free(creationHash);
+    Esys_Free(creationTicket);
+
+    Esys_Free(zPoint);
+    Esys_Free(pubPoint);
     return EXIT_FAILURE;
 }
 
 int
-test_invoke_esapi(ESYS_CONTEXT * esys_context) {
+test_invoke_esys(ESYS_CONTEXT * esys_context) {
     return test_esys_ecdh_keygen(esys_context);
 }
