@@ -18,9 +18,9 @@
 #include "util/aux_util.h"
 
 /** This test is intended to test the definition of a bit field in NV ram and to
- *  test the ESAPI NV_SetBits function.
+ *  test the ESYS NV_SetBits function.
  *
- * Tested ESAPI commands:
+ * Tested ESYS commands:
  *  - Esys_FlushContext() (M)
  *  - Esys_NV_DefineSpace() (M)
  *  - Esys_NV_Read() (M)
@@ -41,6 +41,11 @@ test_esys_nv_ram_set_bits(ESYS_CONTEXT * esys_context)
 {
     TSS2_RC r;
     ESYS_TR nvHandle = ESYS_TR_NONE;
+
+    TPM2B_NV_PUBLIC *nvPublic = NULL;
+    TPM2B_NAME *nvName = NULL;
+    TPM2B_MAX_NV_BUFFER *nv_test_data = NULL;
+
 #ifdef TEST_SESSION
     ESYS_TR session = ESYS_TR_NONE;
     TPMT_SYM_DEF symmetric = {.algorithm = TPM2_ALG_AES,
@@ -104,9 +109,6 @@ test_esys_nv_ram_set_bits(ESYS_CONTEXT * esys_context)
 
     goto_if_error(r, "Error esys define nv space", error);
 
-    TPM2B_NV_PUBLIC *nvPublic;
-    TPM2B_NAME *nvName;
-
     r = Esys_NV_ReadPublic(esys_context,
                            nvHandle,
                            ESYS_TR_NONE,
@@ -142,6 +144,8 @@ test_esys_nv_ram_set_bits(ESYS_CONTEXT * esys_context)
                         bits);
 
     goto_if_error(r, "Error esys nv write", error);
+    Esys_Free(nvPublic);
+    Esys_Free(nvName);
 
     r = Esys_NV_ReadPublic(esys_context,
                            nvHandle,
@@ -161,8 +165,6 @@ test_esys_nv_ram_set_bits(ESYS_CONTEXT * esys_context)
         goto error;
     }
 
-    TPM2B_MAX_NV_BUFFER *nv_test_data;
-
     r = Esys_NV_Read(esys_context,
                      nvHandle,
                      nvHandle,
@@ -179,6 +181,9 @@ test_esys_nv_ram_set_bits(ESYS_CONTEXT * esys_context)
 
     goto_if_error(r, "Error esys nv read", error);
 
+    Esys_Free(nvPublic);
+    Esys_Free(nvName);
+
     r = Esys_NV_ReadPublic(esys_context,
                            nvHandle,
                            ESYS_TR_NONE,
@@ -215,6 +220,9 @@ test_esys_nv_ram_set_bits(ESYS_CONTEXT * esys_context)
     goto_if_error(r, "Error: FlushContext", error);
 #endif
 
+    Esys_Free(nvPublic);
+    Esys_Free(nvName);
+    Esys_Free(nv_test_data);
     return EXIT_SUCCESS;
 
  error:
@@ -242,10 +250,13 @@ test_esys_nv_ram_set_bits(ESYS_CONTEXT * esys_context)
     }
 #endif
 
+    Esys_Free(nvPublic);
+    Esys_Free(nvName);
+    Esys_Free(nv_test_data);
     return EXIT_FAILURE;
 }
 
 int
-test_invoke_esapi(ESYS_CONTEXT * esys_context) {
+test_invoke_esys(ESYS_CONTEXT * esys_context) {
     return test_esys_nv_ram_set_bits(esys_context);
 }
