@@ -13,7 +13,7 @@
 #include "tss2_esys.h"
 
 #include "esys_iutil.h"
-#include "test-esapi.h"
+#include "test-esys.h"
 #define LOGMODULE test
 #include "util/log.h"
 #include "util/aux_util.h"
@@ -22,7 +22,7 @@
  *
  *\b Note: platform authorization needed.
  *
- * Tested ESAPI commands:
+ * Tested ESYS commands:
  *  - Esys_PCR_Allocate() (M)
  *  - Esys_PCR_Event() (M)
  *  - Esys_PCR_Extend() (M)
@@ -42,6 +42,9 @@ test_esys_pcr_basic(ESYS_CONTEXT * esys_context)
     int failure_return = EXIT_FAILURE;
 
     TPMS_CAPABILITY_DATA *savedPCRs = NULL;
+    TPML_PCR_SELECTION *pcrSelectionOut = NULL;
+    TPML_DIGEST *pcrValues = NULL;
+    TPML_DIGEST_VALUES *digestsEvent = NULL;
 
     ESYS_TR  pcrHandle_handle = 16;
     TPML_DIGEST_VALUES digests
@@ -81,8 +84,6 @@ test_esys_pcr_basic(ESYS_CONTEXT * esys_context)
         }
     };
     UINT32 pcrUpdateCounter;
-    TPML_PCR_SELECTION *pcrSelectionOut;
-    TPML_DIGEST *pcrValues;
 
     r = Esys_PCR_Read(
         esys_context,
@@ -107,8 +108,6 @@ test_esys_pcr_basic(ESYS_CONTEXT * esys_context)
     TPM2B_EVENT eventData = { .size = 20,
                               .buffer={0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 0,
                                        1, 2, 3, 4, 5, 6, 7, 8, 9}};
-    TPML_DIGEST_VALUES *digestsEvent;
-
     r = Esys_PCR_Event(
         esys_context,
         pcrHandle_handle,
@@ -143,7 +142,7 @@ test_esys_pcr_basic(ESYS_CONTEXT * esys_context)
         &sizeNeeded,
         &sizeAvailable);
 
-    if ((r & ~TPM2_RC_N_MASK) == TPM2_RC_BAD_AUTH) {
+    if (number_rc(r) == TPM2_RC_BAD_AUTH) {
         /* Platform authorization not possible test will be skipped */
         LOG_WARNING("Platform authorization not possible.");
         failure_return =  EXIT_SKIP;
@@ -166,16 +165,21 @@ test_esys_pcr_basic(ESYS_CONTEXT * esys_context)
     goto_if_error(r, "Error: PCR_Allocate", error);
 
     Esys_Free(savedPCRs);
-
+    Esys_Free(pcrSelectionOut);
+    Esys_Free(pcrValues);
+    Esys_Free(digestsEvent);
     return EXIT_SUCCESS;
 
  error:
-    if (savedPCRs) Esys_Free(savedPCRs);
+    Esys_Free(savedPCRs);
+    Esys_Free(pcrSelectionOut);
+    Esys_Free(pcrValues);
+    Esys_Free(digestsEvent);
     return failure_return;
 
 }
 
 int
-test_invoke_esapi(ESYS_CONTEXT * esys_context) {
+test_invoke_esys(ESYS_CONTEXT * esys_context) {
     return test_esys_pcr_basic(esys_context);
 }
