@@ -13,12 +13,12 @@
 #include "tss2_esys.h"
 
 #include "esys_iutil.h"
-#include "test-esapi.h"
+#include "test-esys.h"
 #define LOGMODULE test
 #include "util/log.h"
 #include "util/aux_util.h"
 
-/** This test is intended to test the ESAPI command Esys_NV_UndefineSpaceSpecial,
+/** This test is intended to test the ESYS command Esys_NV_UndefineSpaceSpecial,
  *  The NV space attributes TPMA_NV_PLATFORMCREATE and TPMA_NV_POLICY_DELETE
  *  have to be set.
  *
@@ -28,7 +28,7 @@
  *
  *\b Note: platform authorization needed.
  *
- * Tested ESAPI commands:
+ * Tested ESYS commands:
  *  - Esys_FlushContext() (M)
  *  - Esys_NV_DefineSpace() (M)
  *  - Esys_NV_UndefineSpaceSpecial() (M)
@@ -50,6 +50,9 @@ test_esys_policy_nv_undefine_special(ESYS_CONTEXT * esys_context)
     ESYS_TR policySession = ESYS_TR_NONE;
     ESYS_TR session = ESYS_TR_NONE;
     int failure_return = EXIT_FAILURE;
+
+    TPM2B_DIGEST *policyDigestTrial = NULL;
+
     /*
      * First the policy value for NV_UndefineSpaceSpecial has to be
      * determined with a policy trial session.
@@ -89,7 +92,6 @@ test_esys_policy_nv_undefine_special(ESYS_CONTEXT * esys_context)
                                );
     goto_if_error(r, "Error: PolicyCommandCode", error);
 
-    TPM2B_DIGEST *policyDigestTrial;
     r = Esys_PolicyGetDigest(esys_context,
                              sessionTrial,
                              ESYS_TR_NONE,
@@ -132,7 +134,8 @@ test_esys_policy_nv_undefine_special(ESYS_CONTEXT * esys_context)
                             &publicInfo,
                             &nvHandle);
 
-    if ((r & ~TPM2_RC_N_MASK) == TPM2_RC_BAD_AUTH) {
+    if (number_rc(r) == TPM2_RC_BAD_AUTH  ||
+        number_rc(r) == TPM2_RC_HIERARCHY) {
         /* Platform authorization not possible test will be skipped */
         LOG_WARNING("Platform authorization not possible.");
         failure_return = EXIT_SKIP;
@@ -197,7 +200,7 @@ test_esys_policy_nv_undefine_special(ESYS_CONTEXT * esys_context)
                                      ESYS_TR_NONE
                                      );
 
-    if ((r & ~TPM2_RC_N_MASK) == TPM2_RC_BAD_AUTH) {
+    if (number_rc(r) == TPM2_RC_BAD_AUTH) {
         /* Platform authorization not possible test will be skipped */
         LOG_WARNING("Platform authorization not possible.");
         failure_return = EXIT_SKIP;
@@ -215,6 +218,7 @@ test_esys_policy_nv_undefine_special(ESYS_CONTEXT * esys_context)
     r = Esys_FlushContext(esys_context, policySession);
     goto_if_error(r, "Flushing context", error);
 
+    Esys_Free(policyDigestTrial);
     return EXIT_SUCCESS;
 
  error:
@@ -237,10 +241,11 @@ test_esys_policy_nv_undefine_special(ESYS_CONTEXT * esys_context)
         }
     }
 
+    Esys_Free(policyDigestTrial);
     return failure_return;
 }
 
 int
-test_invoke_esapi(ESYS_CONTEXT * esys_context) {
+test_invoke_esys(ESYS_CONTEXT * esys_context) {
     return test_esys_policy_nv_undefine_special(esys_context);
 }
