@@ -17,9 +17,9 @@
 #include "util/log.h"
 #include "util/aux_util.h"
 
-/** Test the ESAPI function Esys_TestParms.
+/** Test the ESYS function Esys_TestParms.
  *
- * Tested ESAPI commands:
+ * Tested ESYS commands:
  *  - Esys_TestParms() (M)
  *
  * @param[in,out] esys_context The ESYS_CONTEXT.
@@ -66,6 +66,6 @@ test_esys_testparms(ESYS_CONTEXT * esys_context)
 }
 
 int
-test_invoke_esapi(ESYS_CONTEXT * esys_context) {
+test_invoke_esys(ESYS_CONTEXT * esys_context) {
     return test_esys_testparms(esys_context);
 }
