@@ -16,9 +16,9 @@
 #include "util/log.h"
 #include "util/aux_util.h"
 
-/** Test the ESAPI functions for TPM tests.
+/** Test the ESYS functions for TPM tests.
  *
- * Tested ESAPI commands:
+ * Tested ESYS commands:
  *  - Esys_GetTestResult() (M)
  *  - Esys_IncrementalSelfTest() (M)
  *  - Esys_SelfTest() (M)
@@ -64,6 +64,6 @@ test_esys_tpm_tests(ESYS_CONTEXT * esys_context)
 }
 
 int
-test_invoke_esapi(ESYS_CONTEXT * esys_context) {
+test_invoke_esys(ESYS_CONTEXT * esys_context) {
     return test_esys_tpm_tests(esys_context);
 }
