@@ -10,7 +10,7 @@
 #include <stdint.h>
 
 /* Default TCTI */
-#define TCTI_DEFAULT      SOCKET_TCTI
+#define TCTI_DEFAULT      SWTPM_TCTI
 #define TCTI_DEFAULT_STR  "socket"
 
 /* Defaults for Device TCTI */
@@ -30,6 +30,7 @@ typedef enum {
     UNKNOWN_TCTI,
     DEVICE_TCTI,
     SOCKET_TCTI,
+    SWTPM_TCTI,
     FUZZING_TCTI,
     N_TCTI,
 } TCTI_TYPE;
